@@ -4,8 +4,9 @@ from keytotext import pipeline
 
 st.set_page_config(
     page_title="Text Generation Using Keywords",
-    layout="wide",
-    initial_sidebar_state="expanded", )
+    #layout="wide",
+    #initial_sidebar_state="expanded",
+)
 
 
 @st.cache(suppress_st_warning=True, ttl=1000)
@@ -33,7 +34,7 @@ def display():
 
     keywords = st_tags(label='## Enter Keywords:',
                        text='Press enter to add more',
-                       value=['India', 'Capital', 'Delhi'],
+                       value=['India', 'Capital', 'New Delhi'],
                        maxtags=mt,
                        key='1')
 
