@@ -14,7 +14,6 @@ class K2TPipeline:
         self,
         model: PreTrainedModel,
         tokenizer: PreTrainedTokenizer,
-
         use_cuda: bool
     ):
         self.model = model
@@ -90,6 +89,12 @@ SUPPORTED_TASKS = {
         "default": {
             "model": "gagan3012/k2t-tiny",
         },
+    },
+    "k2t-base": {
+        "impl": K2TPipeline,
+        "default": {
+            "model": "gagan3012/k2t-base",
+        },
     }
 }
 
@@ -99,7 +104,35 @@ def pipeline(
     model: Optional = None,
     tokenizer: Optional[Union[str, PreTrainedTokenizer]] = None,
     use_cuda: Optional[bool] = True,
-):
+    ) -> K2TPipeline:
+    """
+
+    :param task:
+    (:obj:`str`):
+            The task defining which pipeline will be returned. Currently accepted tasks are:
+            - :obj:`"k2t"`: will return a :class:`K2TPipeline` which is based on the k2t model based on t5-small
+            - :obj:`"k2t-tiny"`: will return a :class:`K2TPipeline` which is based on the k2t model based on t5-tiny
+            - :obj:`"k2t-base"`: will return a :class:`K2TPipeline` which is based on the k2t model based on t5-base
+    :param model:
+    (:obj:`str` or `optional`):
+            The model that will be used by the pipeline to make predictions.
+
+            If not provided, the default for the :obj:`task` will be loaded.
+    :param tokenizer:
+    (:obj:`str` or `optional`):
+            The tokenizer that will be used by the pipeline to encode data for the model. This can be a model
+            identifier or an actual pretrained tokenizer inheriting from :class:`~transformers.PreTrainedTokenizer`.
+
+            If not provided, the default tokenizer for the given :obj:`model` will be loaded (if it is a string).
+    :param use_cuda:
+    (:obj:`bool`, `optional`, defaults to :obj:`True`):
+            Whether or not to use a GPU or not Default: True
+    :return:
+    (:class:):
+            `K2TPipeline`: A Keytotext pipeline for the task.
+
+    """
+
     if task not in SUPPORTED_TASKS:
         raise KeyError(
             "Unknown task {}, available tasks are {}".format(
@@ -131,3 +164,7 @@ def pipeline(
 
     if task == "k2t":
         return task_class(model=model, tokenizer=tokenizer, use_cuda=use_cuda)
+    if task == "k2t-tiny":
+        return task_class(model=model, tokenizer=tokenizer, use_cuda=use_cuda)
+    if task == "k2t-base":
+        return task_class(model=model, tokenizer=tokenizer, use_cuda=use_cuda)
